@@ -19,6 +19,7 @@ class RateLimitedException(Exception):
     """The error when number of requests exceeds the capacity"""
 
     def __init__(self, msg, original_exception=None):
+        """create exception object"""
         if original_exception is not None:
             super().__init__(msg + (": %s" % original_exception))
         else:
@@ -27,20 +28,32 @@ class RateLimitedException(Exception):
 
 
 class InternalError502Exception(Exception):
-    """The error when SQL Query returns a 502 internal error"""
+    """The error when Data Engine returns a 502 internal error"""
 
     def __init__(self, msg, original_exception=None):
+        """create exception object"""
         if original_exception is not None:
             super().__init__(msg + (": %s" % original_exception))
         else:
             super().__init__(msg)
         self.original_exception = original_exception
 
+class InternalError524Exception(Exception):
+    """The error when Data Engine returns a 524 internal error"""
+
+    def __init__(self, msg, original_exception=None):
+        """create exception object"""
+        if original_exception is not None:
+            super().__init__(msg + (": %s" % original_exception))
+        else:
+            super().__init__(msg)
+        self.original_exception = original_exception
 
 class CosUrlNotFoundException(Exception):
     """The error when the Cloud-Object Storage (COS) URL being used is invalid or not accessible"""
 
     def __init__(self, msg, original_exception=None):
+        """create exception object"""
         if original_exception is not None:
             super().__init__(msg + (": %s" % original_exception))
         else:
@@ -52,6 +65,7 @@ class CosUrlInaccessibleException(Exception):
     """The error when the Cloud-Object Storage (COS) URL being used is not accessible"""
 
     def __init__(self, msg, original_exception=None):
+        """create exception object"""
         if original_exception is not None:
             super().__init__(msg + (": %s" % original_exception))
         else:
@@ -60,9 +74,10 @@ class CosUrlInaccessibleException(Exception):
 
 
 class SqlQueryCrnInvalidFormatException(Exception):
-    """The error when the SQL Query CRN is not correct"""
+    """The error when the Data Engine CRN is not correct"""
 
     def __init__(self, msg, original_exception=None):
+        """create exception object"""
         if original_exception is not None:
             super().__init__(msg + (": %s" % original_exception))
         else:
@@ -75,6 +90,7 @@ class SqlQueryInvalidPlanException(Exception):
     e.g. need to upgrade to Standard Plan or higher"""
 
     def __init__(self, msg, original_exception=None):
+        """create exception object"""
         if original_exception is not None:
             super().__init__(msg + (": %s" % original_exception))
         else:
@@ -86,6 +102,7 @@ class SqlQueryFailException(Exception):
     """The error raised when a running sql job fails, e.g. timeout"""
 
     def __init__(self, msg, original_exception=None):
+        """create exception object"""
         if original_exception is not None:
             super().__init__(msg + (": %s" % original_exception))
         else:
@@ -97,6 +114,7 @@ class SqlQueryCreateTableException(SqlQueryFailException):
     """The error raised when a running create-table sql job fails"""
 
     def __init__(self, msg, original_exception=None):
+        """create exception object"""
         if original_exception is not None:
             super().__init__(msg + (": %s" % original_exception))
         else:
@@ -108,6 +126,7 @@ class SqlQueryDropTableException(SqlQueryFailException):
     """The error raised when a running drop-table sql job fails"""
 
     def __init__(self, msg, original_exception=None):
+        """create exception object"""
         if original_exception is not None:
             super().__init__(msg + (": %s" % original_exception))
         else:
@@ -119,6 +138,7 @@ class SqlQueryInvalidFormatException(SqlQueryFailException):
     """The error raised when the format of COS URL is not valid"""
 
     def __init__(self, msg, original_exception=None):
+        """create exception object"""
         if original_exception is not None:
             super().__init__(msg + (": %s" % original_exception))
         else:
@@ -130,6 +150,19 @@ class UnsupportedStorageFormatException(Exception):
     """The error when the SQL uses a format of data that has not been supported yet"""
 
     def __init__(self, msg, original_exception=None):
+        """create exception object"""
+        if original_exception is not None:
+            super().__init__(msg + (": %s" % original_exception))
+        else:
+            super().__init__(msg)
+        self.original_exception = original_exception
+
+
+class InternalErrorException(Exception):
+    """The error when Data Engine crash with an internal error"""
+
+    def __init__(self, msg, original_exception=None):
+        """create exception object"""
         if original_exception is not None:
             super().__init__(msg + (": %s" % original_exception))
         else:
